import 'package:basic_flutter_theme/src/styles/styles.dart';
import 'package:flutter/material.dart';

class BasicButton extends StatelessWidget {
  const BasicButton({
    Key? key,
    this.isFullColor = false,
    required this.onPressed,
    this.text,
    this.child,
    this.width,
    this.height,
    this.padding,
    this.background,
    this.shadowColor = Colors.transparent,
    this.boxShadow,
    this.shape,
    this.borderColor,
    this.borderWidth,
    this.clickColor,
    this.radius = BasicCorners.corner5,
    this.textColor,
    this.fontSize,
    this.textStyle,
    this.textAlign = TextAlign.center,
    this.maxLines = 4,
    this.alignment,
  }) : super(key: key);

  final bool isFullColor;
  final VoidCallback onPressed;
  final String? text;
  final Widget? child;
  final double? width;
  final double? height;
  final EdgeInsets? padding;
  final Color? background;
  final Color shadowColor;
  final List<BoxShadow>? boxShadow;
  final OutlinedBorder? shape;
  final Color? borderColor;
  final double? borderWidth;
  final Color? clickColor;
  final double radius;
  final Color? textColor;
  final double? fontSize;
  final TextStyle? textStyle;
  final TextAlign textAlign;
  final int maxLines;
  final AlignmentGeometry? alignment;

  @override
  Widget build(BuildContext context) => Container(
        padding: EdgeInsets.zero,
        margin: EdgeInsets.zero,
        height: height,
        width: width,
        decoration: BoxDecoration(boxShadow: boxShadow),
        child: ElevatedButton(
          key: key,
          onPressed: onPressed,
          style: ElevatedButton.styleFrom(
            alignment: alignment,
            foregroundColor: clickColor,
            backgroundColor:
                background ?? (isFullColor ? BasicAppColors().primary : BasicAppColors.white),
            shape: shape ??
                RoundedRectangleBorder(
                  side: BorderSide(
                    color: borderColor ?? (isFullColor ? Colors.transparent : BasicAppColors.grey),
                    width: borderWidth ?? (isFullColor ? 0 : BasicBorders.thin),
                  ),
                  borderRadius: BorderRadius.circular(radius),
                ),
            padding: EdgeInsets.zero,
            shadowColor: shadowColor,
            elevation: 0,
            minimumSize: Size.zero,
          ),
          child: Padding(
            padding: padding ??
                EdgeInsets.symmetric(
                  horizontal: BasicPaddings().p18,
                  vertical: BasicPaddings().p12,
                ),
            child: child ??
                Text(
                  text ?? '',
                  textAlign: TextAlign.center,
                  maxLines: maxLines,
                  style: textStyle ??
                      BasicTextStyles.body.copyWith(
                        color: textColor ??
                            (isFullColor ? BasicAppColors.white : BasicAppColors.black),
                        height: 0,
                        fontSize: fontSize,
                      ),
                ),
          ),
        ),
      );
}
