import 'package:basic_flutter_theme/basic_flutter_theme.dart';
import 'package:flutter/material.dart';

class BasicButtonDropdown extends StatefulWidget {
  const BasicButtonDropdown({
    Key? key,
    required this.titleButton,
    this.children = const [],
    required this.onPressedTitleButton,
    required this.onPressedItem,
    this.isFullColor = false,
    this.width,
    this.height,
    this.padding,
    this.background,
    this.shadowColor = Colors.transparent,
    this.boxShadow,
    this.shape,
    this.borderColor,
    this.borderWidth,
    this.clickColor,
    this.radius = BasicCorners.corner5,
    this.textColor,
    this.fontSize,
    this.textStyle,
    this.textAlign = TextAlign.center,
    this.maxLines = 4,
    this.alignment,
    this.colorWhenDropdown,
  }) : super(key: key);

  final Widget titleButton;
  final List<Widget> children;
  final VoidCallback onPressedTitleButton;
  final Function(int) onPressedItem;
  final bool isFullColor;
  final double? width;
  final double? height;
  final EdgeInsets? padding;
  final Color? background;
  final Color shadowColor;
  final List<BoxShadow>? boxShadow;
  final OutlinedBorder? shape;
  final Color? borderColor;
  final double? borderWidth;
  final Color? clickColor;
  final double radius;
  final Color? textColor;
  final double? fontSize;
  final TextStyle? textStyle;
  final TextAlign textAlign;
  final int maxLines;
  final AlignmentGeometry? alignment;
  final Color? colorWhenDropdown;

  @override
  State<BasicButtonDropdown> createState() => _BasicButtonDropdownState();
}

class _BasicButtonDropdownState extends State<BasicButtonDropdown>
    with SingleTickerProviderStateMixin {
  late final AnimationController _controller;
  late final Animation<double> _animation;
  final double _heightButton = 52.scaleSize;
  late final double _heightDropdown;

  @override
  void initState() {
    super.initState();
    _heightDropdown = widget.children.length * _heightButton;
    _controller = AnimationController(
      vsync: this,
      duration: const Duration(milliseconds: 100),
    );
    _animation = Tween<double>(
      begin: 0,
      end: _heightDropdown,
    ).animate(
      CurvedAnimation(
        parent: _controller,
        curve: Curves.bounceInOut,
      ),
    );
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  void toggle() {
    if (_controller.isDismissed) {
      _controller.forward();
    } else {
      _controller.reverse();
    }
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
        animation: _animation,
        builder: (context, child) {
          final mainColor = _animation.value == 0
              ? widget.background
              : widget.colorWhenDropdown ?? widget.background;
          return Column(
            children: [
              BasicButton(
                onPressed: () {
                  toggle();
                  widget.onPressedTitleButton();
                },
                isFullColor: widget.isFullColor,
                width: widget.width,
                height: widget.height,
                padding: widget.padding,
                background: mainColor,
                shadowColor: widget.shadowColor,
                boxShadow: widget.boxShadow,
                shape: widget.shape,
                borderColor: widget.borderColor,
                borderWidth: widget.borderWidth,
                clickColor: widget.clickColor,
                radius: widget.radius,
                textColor: widget.textColor,
                fontSize: widget.fontSize,
                textStyle: widget.textStyle,
                textAlign: widget.textAlign,
                maxLines: widget.maxLines,
                alignment: widget.alignment,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    widget.titleButton,
                    Icon(
                      _animation.value >= _heightDropdown
                          ? Icons.expand_more_rounded
                          : Icons.expand_less_rounded,
                      color: widget.textStyle?.color,
                    ),
                  ],
                ),
              ),
              ...listDropdownButton(animationHeight: _animation.value),
            ],
          );
        });
  }

  List<Widget> listDropdownButton({
    double? animationHeight,
  }) {
    final mainColor =
        _animation.value == 0 ? widget.background : widget.colorWhenDropdown ?? widget.background;
    return widget.children.map(
      (e) {
        final index = widget.children.indexOf(e);
        if (_animation.value > index * _heightButton) {
          return BasicButton(
            onPressed: () => widget.onPressedItem(index),
            isFullColor: widget.isFullColor,
            width: widget.width,
            height: widget.height,
            padding: widget.padding,
            background: mainColor,
            shadowColor: widget.shadowColor,
            boxShadow: widget.boxShadow,
            shape: widget.shape,
            borderColor: widget.borderColor,
            borderWidth: widget.borderWidth,
            clickColor: widget.clickColor,
            radius: widget.radius,
            textColor: widget.textColor,
            fontSize: widget.fontSize,
            textStyle: widget.textStyle,
            textAlign: widget.textAlign,
            maxLines: widget.maxLines,
            alignment: widget.alignment,
            child: widget.children[index],
          );
        }
        return const SizedBox.shrink();
      },
    ).toList();
  }
}
